@@ -1,3 +1,3 @@
 __version__ = "0.2.9"
 __author__ = "David Li <davidli012345@gmail.com>"
-from cad_tickers.exchanges import *
\ No newline at end of file
+# from cad_tickers.exchanges import *
\ No newline at end of file
